@@ -50,7 +50,7 @@ import wxFrame2, about
 
 from odexml import Model
 import PlotFigure as PF
-from BIP.Bayes import Melding as meld
+#from BIP.Bayes import Melding as meld
 from time import *
 import icones
 import MBicon
